@@ -4,12 +4,9 @@ Expose Twisted's event loop to threaded programs.
 
 from __future__ import absolute_import
 
+import select
 import threading
 import weakref
-try:
-    from queue import Queue, Empty
-except ImportError:
-    from Queue import Queue, Empty
 from functools import wraps
 
 from twisted.python import threadable
@@ -115,9 +112,9 @@ class EventualResult(object):
         """
         self._deferred = deferred
         self._reactor = _reactor
-        self._queue = Queue()
+        self._value = None
         self._result_retrieved = False
-        self._result_set = False
+        self._result_set = threading.Event()
         if deferred is not None:
             self._connect_deferred(deferred)
 
@@ -146,20 +143,16 @@ class EventualResult(object):
         Deferred firing, or as a result of ResultRegistry.stop(). So, no need
         for thread-safety.
         """
-        if self._result_set:
+        if self._result_set.isSet():
             return
-        self._result_set = True
-        self._queue.put(result)
+        self._value = result
+        self._result_set.set()
 
     def __del__(self):
-        if self._result_retrieved:
+        if self._result_retrieved or not self._result_set.isSet():
             return
-        try:
-            result = self._queue.get(timeout=0)
-        except Empty:
-            return
-        if isinstance(result, Failure):
-            err(result, "Unhandled error in EventualResult")
+        if isinstance(self._value, Failure):
+            err(self._value, "Unhandled error in EventualResult")
 
     def cancel(self):
         """
@@ -189,13 +182,13 @@ class EventualResult(object):
         if timeout is None:
             # Queue.get(None) won't get interrupted by Ctrl-C...
             timeout = 2 ** 31
-        try:
-            result = self._queue.get(timeout=timeout)
-        except Empty:
+        self._result_set.wait(timeout)
+        # In Python 2.6 we can't rely on the return result of wait(), so we
+        # have to check manually:
+        if not self._result_set.is_set():
             raise TimeoutError()
         self._result_retrieved = True
-        self._queue.put(result) # allow next _result() call to get a value out
-        return result
+        return self._value
 
     def wait(self, timeout=None):
         """
@@ -255,13 +248,18 @@ class ThreadLogObserver(object):
     In particular, used to wrap PythonLoggingObserver, so that blocking
     logging.py Handlers don't block the event loop.
     """
-
-    _DONE = object()
-
     def __init__(self, observer):
         self._observer = observer
-        self._queue = Queue()
-        self._thread = threading.Thread(target=self._reader)
+        if getattr(select, "poll", None):
+            from twisted.internet.pollreactor import PollReactor
+            reactorFactory = PollReactor
+        else:
+            from twisted.internet.selectreactor import SelectReactor
+            reactorFactory = SelectReactor
+        self._logWritingReactor = reactorFactory()
+        self._logWritingReactor._registerAsIOThread = False
+        self._thread = threading.Thread(target=self._reader,
+                                        name="CrochetLogWriter")
         self._thread.start()
 
     def _reader(self):
@@ -269,23 +267,19 @@ class ThreadLogObserver(object):
         Runs in a thread, reads messages from a queue and writes them to
         the wrapped observer.
         """
-        while True:
-            item = self._queue.get()
-            if item is self._DONE:
-                return
-            self._observer(item)
+        self._logWritingReactor.run(installSignalHandlers=False)
 
     def stop(self):
         """
         Stop the thread.
         """
-        self._queue.put(self._DONE)
+        self._logWritingReactor.callFromThread(self._logWritingReactor.stop)
 
     def __call__(self, msg):
         """
         A log observer that writes to a queue.
         """
-        self._queue.put(msg)
+        self._logWritingReactor.callFromThread(self._observer, msg)
 
 
 class EventLoop(object):
@@ -347,7 +341,8 @@ class EventLoop(object):
             # shut down:
             self._reactor.addSystemEventTrigger("after", "shutdown", observer.stop)
         t = threading.Thread(
-            target=lambda: self._reactor.run(installSignalHandlers=False))
+            target=lambda: self._reactor.run(installSignalHandlers=False),
+            name="CrochetReactor")
         t.start()
         self._atexit_register(self._reactor.callFromThread,
                               self._reactor.stop)
