@@ -16,24 +16,26 @@ from twisted.internet.defer import succeed, Deferred, fail, CancelledError
 from twisted.python.failure import Failure
 from twisted.python import threadable
 from twisted.python.runtime import platform
-try:
-    from twisted.internet.process import reapAllProcesses
-except ImportError:
+if platform.type == "posix":
+    try:
+        from twisted.internet.process import reapAllProcesses
+    except (SyntaxError, ImportError):
+        if sys.version_info < (3, 3, 0):
+            raise
+        else:
+            # Process support is still not ported to Python 3 on some versions
+            # of Twisted.
+            reapAllProcesses = None
+else:
+    # waitpid() is only necessary on POSIX:
     reapAllProcesses = None
-except SyntaxError:
-    if sys.version_info < (3, 3, 0):
-        raise
-    else:
-        # Process support is still not ported to Python 3 on some versions of
-        # Twisted.
-        reapAllProcesses = None
 
 from .._eventloop import (EventLoop, EventualResult, TimeoutError,
                           ResultRegistry, ReactorStopped)
 from .test_setup import FakeReactor
 from .. import (_main, setup, in_reactor, retrieve_result, _store, no_setup,
                 run_in_reactor, wait_for_reactor)
-
+from ..tests import crochet_directory
 
 
 class ResultRegistryTests(TestCase):
@@ -304,18 +306,29 @@ import crochet
 crochet.setup()
 from twisted.internet.defer import Deferred
 
+if sys.platform.startswith('win'):
+    signal.signal(signal.SIGBREAK, signal.default_int_handler)
+    sig_int=signal.CTRL_BREAK_EVENT
+    sig_kill=signal.SIGTERM
+else:
+    sig_int=signal.SIGINT
+    sig_kill=signal.SIGKILL
+
+
 def interrupt():
     time.sleep(0.1) # Make sure we've hit wait()
-    os.kill(os.getpid(), signal.SIGINT)
+    os.kill(os.getpid(), sig_int)
     time.sleep(1)
     # Still running, test shall fail...
-    os.kill(os.getpid(), signal.SIGKILL)
+    os.kill(os.getpid(), sig_kill)
+
 t = threading.Thread(target=interrupt)
 t.setDaemon(True)
 t.start()
 
 d = Deferred()
 e = crochet.EventualResult(d)
+
 try:
     # Queue.get() has special non-interruptible behavior if not given timeout,
     # so don't give timeout here.
@@ -323,7 +336,13 @@ try:
 except KeyboardInterrupt:
     sys.exit(23)
 """
-        process = subprocess.Popen([sys.executable, "-c", program])
+        kw = { 'cwd': crochet_directory }
+        # on Windows the only way to interrupt a subprocess reliably is to 
+        # create a new process group:
+        # http://docs.python.org/2/library/subprocess.html#subprocess.CREATE_NEW_PROCESS_GROUP
+        if platform.type.startswith('win'):
+            kw['creationflags'] = subprocess.CREATE_NEW_PROCESS_GROUP
+        process = subprocess.Popen([sys.executable, "-c", program], **kw)
         self.assertEqual(process.wait(), 23)
 
     def test_reactor_stop_unblocks_EventualResult(self):
@@ -372,7 +391,8 @@ try:
 except crochet.ReactorStopped:
     sys.exit(23)
 """
-        process = subprocess.Popen([sys.executable, "-c", program])
+        process = subprocess.Popen([sys.executable, "-c", program],
+                                   cwd=crochet_directory)
         self.assertEqual(process.wait(), 23)
 
     def test_reactor_stop_unblocks_EventualResult_in_threadpool(self):
@@ -406,7 +426,8 @@ reactor.callInThread(inthread)
 time.sleep(1)
 sys.exit(result[0])
 """
-        process = subprocess.Popen([sys.executable, "-c", program])
+        process = subprocess.Popen([sys.executable, "-c", program],
+                                   cwd=crochet_directory)
         self.assertEqual(process.wait(), 23)
 
     def test_immediate_cancel(self):
@@ -437,7 +458,8 @@ except CancelledError:
 else:
     sys.exit(3)
 """
-        process = subprocess.Popen([sys.executable, "-c", program])
+        process = subprocess.Popen([sys.executable, "-c", program],
+                                   cwd=crochet_directory,)
         self.assertEqual(process.wait(), 23)
 
 
@@ -723,12 +745,22 @@ import crochet
 crochet.setup()
 from twisted.internet.defer import Deferred
 
+if sys.platform.startswith('win'):
+    signal.signal(signal.SIGBREAK, signal.default_int_handler)
+    sig_int=signal.CTRL_BREAK_EVENT
+    sig_kill=signal.SIGTERM
+else:
+    sig_int=signal.SIGINT
+    sig_kill=signal.SIGKILL
+
+
 def interrupt():
     time.sleep(0.1) # Make sure we've hit wait()
-    os.kill(os.getpid(), signal.SIGINT)
+    os.kill(os.getpid(), sig_int)
     time.sleep(1)
     # Still running, test shall fail...
-    os.kill(os.getpid(), signal.SIGKILL)
+    os.kill(os.getpid(), sig_kill)
+
 t = threading.Thread(target=interrupt)
 t.setDaemon(True)
 t.start()
@@ -742,7 +774,10 @@ try:
 except KeyboardInterrupt:
     sys.exit(23)
 """
-        process = subprocess.Popen([sys.executable, "-c", program])
+        kw = { 'cwd': crochet_directory }
+        if platform.type.startswith('win'):
+            kw['creationflags'] = subprocess.CREATE_NEW_PROCESS_GROUP
+        process = subprocess.Popen([sys.executable, "-c", program], **kw)
         self.assertEqual(process.wait(), 23)
 
     def test_reactor_stop_unblocks(self):
@@ -769,7 +804,8 @@ try:
 except crochet.ReactorStopped:
     sys.exit(23)
 """
-        process = subprocess.Popen([sys.executable, "-c", program])
+        process = subprocess.Popen([sys.executable, "-c", program],
+                                   cwd=crochet_directory)
         self.assertEqual(process.wait(), 23)
 
 
